@@ -1,7 +1,7 @@
 package CPAN::Reporter::Config;
 use strict; 
 use vars qw/$VERSION/;
-$VERSION = '1.15'; 
+$VERSION = '1.16'; 
 $VERSION = eval $VERSION;
 
 use Config::Tiny ();
@@ -313,7 +313,9 @@ sub _config_spec { return %option_specs }
 #--------------------------------------------------------------------------#
 
 sub _get_config_dir {
-    if ( defined $ENV{PERL_CPAN_REPORTER_DIR} ) {
+    if ( defined $ENV{PERL_CPAN_REPORTER_DIR} && 
+         length  $ENV{PERL_CPAN_REPORTER_DIR} 
+    ) {
         return $ENV{PERL_CPAN_REPORTER_DIR};
     }
     else {
@@ -328,7 +330,9 @@ sub _get_config_dir {
 #--------------------------------------------------------------------------#
 
 sub _get_config_file {
-    if ( defined $ENV{PERL_CPAN_REPORTER_CONFIG} ) {
+    if (  defined $ENV{PERL_CPAN_REPORTER_CONFIG} &&
+          length  $ENV{PERL_CPAN_REPORTER_CONFIG} 
+    ) {
         return $ENV{PERL_CPAN_REPORTER_CONFIG};
     }
     else {
@@ -668,7 +672,8 @@ will be halted after this many seconds; useful for unattended smoke testing
 to stop after some amount of time; generally, this should be large -- 
 900 seconds or more -- as some distributions' tests take quite a long time to 
 run.  On MSWin32, [Win32::Job] is a needed and trying to kill a processes may 
-actually deadlock in some situations -- so use at your own risk
+actually deadlock in some situations -- so use at your own risk.  On other
+platforms, [Proc::Killfam] is required.
 * {editor = <editor>} -- editor to use to edit the test report; if not set,
 Test::Reporter will use environment variables {VISUAL}, {EDITOR} or {EDIT}
 (in that order) to find an editor 
